package logging

import (
	"fmt"
	"os"
)

type Logger struct {
	level    Level
	backends []Backend
}

func NewLogger() (l *Logger) {
	l = &Logger{
		level: DEFAULT_LEVEL,
	}
	return
}

func (l *Logger) AddBackend(b Backend) {
	l.backends = append(l.backends, b)
}

func (l *Logger) SetLevel(level Level) {
	l.level = level
	for _, backend := range l.backends {
		backend.SetLevel(level)
	}
}

func (l *Logger) Log(level Level, m string) {
	r := NewRecord(level, m)
	for _, backend := range l.backends {
		//Should be dereferenced automatically ?
		backend.Write(r)
	}
}

func (l *Logger) Debug(text string) {
	l.Log(DEBUG, text)
}

func (l *Logger) Debugf(text string, args ...interface{}) {
	l.Debug(fmt.Sprintf(text, args...))
}

func (l *Logger) Info(text string) {
	l.Log(INFO, text)
}

func (l *Logger) Infof(text string, args ...interface{}) {
	l.Info(fmt.Sprintf(text, args...))
}

func (l *Logger) Warning(text string) {
	l.Log(WARNING, text)
}

func (l *Logger) Warningf(text string, args ...interface{}) {
	l.Warning(fmt.Sprintf(text, args...))
}

func (l *Logger) Error(text string) {
	l.Log(ERROR, text)
}

func (l *Logger) Errorf(text string, args ...interface{}) {
	l.Error(fmt.Sprintf(text, args...))
}

func (l *Logger) Critical(text string) {
	l.Log(CRITICAL, text)
}

func (l *Logger) Criticalf(text string, args ...interface{}) {
	l.Critical(fmt.Sprintf(text, args...))
}

func (l *Logger) Fatal(text string) {
	l.Log(DEBUG, text)
	os.Exit(100)
}

func (l *Logger) Fatalf(text string, args ...interface{}) {
	l.Fatal(fmt.Sprintf(text, args...))
}
